/*****************************************************************************
 * PDSCANNER - a port scanner for GNOME                                      *
 * Copyright (C) 2000 Scott Guilbeaux <scottg@viptx.net>                     *
 *                                                                           *
 * This program is free software; you can redistribute it and/or modify      *
 * it under the terms of the GNU General Public License as published by      *
 * the Free Software Foundation; either version 2 of the License, or         *
 * (at your option) any later version.                                       *
 *                                                                           *
 * This program is distributed in the hope that it will be useful,           *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
 * GNU General Public License for more details.                              *
 *                                                                           *
 * You should have received a copy of the GNU General Public License         *
 * along with this program; if not, write to the Free Software               *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA *
 *****************************************************************************/

#include "pdscanner.h"

/* Called whenever "exit" is selected from
 * the gui */

void pdscanner_quit(GtkWidget *widget, GdkEvent *event, gpointer data)
{
#ifdef DEBUG
   g_print("%s: shutting down\n", PACKAGE);
#endif
   
   gtk_main_quit();
}

/* Create our kick ass about dialog ; ) */

void pdscanner_about(GtkWidget *widget, GdkEvent *event, gpointer data)
{
   static GtkWidget *dialog = NULL;
   const gchar *authors[] = { "Scott Guilbeaux <scottg@viptx.net>", NULL };
   
   if(dialog == NULL)
     {
	dialog = gnome_about_new(PACKAGE, VERSION,
				 COPYRIGHT, authors,
				 DESCRIPTION, "pdscanner-scott.xpm");
	gtk_signal_connect(GTK_OBJECT(dialog), "destroy",
			   GTK_SIGNAL_FUNC(gtk_widget_destroyed),
			   &dialog);
	gnome_dialog_set_parent(GNOME_DIALOG(dialog), GTK_WINDOW(pdscanner.main_window));
	gtk_widget_show(dialog);
     }
}

/* Callback that starts our port scanning and
 * does some error checking */

void pdscanner_scan(GtkWidget *widget, GdkEvent *event, gpointer data)
{
   gchar *message;
   pthread_t thread;
   
   gtk_clist_clear(GTK_CLIST(pdscanner.output_list));
   gtk_widget_set_sensitive(GTK_WIDGET(pdscanner.scan_button), FALSE);
   gtk_widget_set_sensitive(GTK_WIDGET(pdscanner.clear_button), FALSE);
   
   target_host.host_name = gtk_entry_get_text(GTK_ENTRY(pdscanner.host_entry));
   target_host.starting_port = atoi(gtk_entry_get_text(GTK_ENTRY(pdscanner.start_entry)));
   target_host.ending_port = atoi(gtk_entry_get_text(GTK_ENTRY(pdscanner.end_entry)));
  
   if(strlen(target_host.host_name) <= 0)
     {
	gnome_error_dialog_parented("You must enter a host to scan!", GTK_WINDOW(pdscanner.main_window));
	gtk_widget_set_sensitive(GTK_WIDGET(pdscanner.scan_button), TRUE);
	return;
     }
   if((target_host.starting_port <= 0) || (target_host.ending_port <= 0))
     {
	gnome_error_dialog_parented("You must enter a starting port and ending port and they must be greater than zero!", 
				    GTK_WINDOW(pdscanner.main_window));
	gtk_widget_set_sensitive(GTK_WIDGET(pdscanner.scan_button), TRUE);
	return;
     }
   
   message = g_strdup_printf("Looking up %s", target_host.host_name);
   gnome_appbar_set_status(GNOME_APPBAR(pdscanner.status_bar), message);
#ifdef DEBUG
   g_print(_("%s: looking up %s\n"), PACKAGE, target_host.host_name);
#endif
   verify_host();
   
   if(target_host.valid)
     {
	gnome_appbar_set_status(GNOME_APPBAR(pdscanner.status_bar), "Scanning...");
	target_host.current_port = target_host.starting_port;
	pthread_create(&thread, NULL, (void *)check_ports, NULL);
	pthread_detach(thread);
#ifdef DEBUG
	g_print("%s: Thread created and detached\n", PACKAGE);
#endif
     }
   else
     {
	message = g_strdup_printf("%s: Non existant host or domain!", target_host.host_name);
	gnome_error_dialog_parented(message, GTK_WINDOW(pdscanner.main_window));
	gnome_appbar_set_status(GNOME_APPBAR(pdscanner.status_bar), PACKAGE);
	gtk_widget_set_sensitive(GTK_WIDGET(pdscanner.scan_button), TRUE);
	gtk_widget_set_sensitive(GTK_WIDGET(pdscanner.clear_button), TRUE);
     }
}

/* Simple callback.  Just clears the output list */

void pdscanner_clear(GtkWidget *widget, GdkEvent *event, gpointer data)
{
   gtk_clist_clear(GTK_CLIST(pdscanner.output_list));
}
