/*****************************************************************************
 * PDSCANNER - a port scanner for gnome                                      *
 * Copyright (C) 2000 Scott Guilbeaux <scottg@viptx.net>                     *
 *                                                                           *
 * This program is free software; you can redistribute it and/or modify      *
 * it under the terms of the GNU General Public License as published by      *
 * the Free Software Foundation; either version 2 of the License, or         *
 * (at your option) any later version.                                       *
 *                                                                           *
 * This program is distributed in the hope that it will be useful,           *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
 * GNU General Public License for more details.                              *
 *                                                                           *
 * You should have received a copy of the GNU General Public License         *
 * along with this program; if not, write to the Free Software               *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA *
 *****************************************************************************/

#include "pdscanner.h"
#include "pixmaps/scan.xpm"
#include "pixmaps/clear.xpm"

/* Menubar stuff */
GnomeUIInfo file_menu[] = {
   GNOMEUIINFO_MENU_EXIT_ITEM(pdscanner_quit, NULL),
   GNOMEUIINFO_END
};

GnomeUIInfo edit_menu[] = {
     {
	GNOME_APP_UI_ITEM,
	N_("_Clear"),
	N_("Clear the output list"),
	pdscanner_clear, NULL,
	NULL,
	GNOME_APP_PIXMAP_DATA, clear_xpm,
	'C', GDK_CONTROL_MASK, NULL
     },
   GNOMEUIINFO_END
};

GnomeUIInfo help_menu[] = {
   GNOMEUIINFO_MENU_ABOUT_ITEM(pdscanner_about, NULL),
   GNOMEUIINFO_END
};

GnomeUIInfo menubar[] = {
   GNOMEUIINFO_MENU_FILE_TREE(file_menu),
   GNOMEUIINFO_MENU_EDIT_TREE(edit_menu),
   GNOMEUIINFO_MENU_HELP_TREE(help_menu),
   GNOMEUIINFO_END
};

/* Toolbar stuff */
GnomeUIInfo toolbar[] = {
   GNOMEUIINFO_ITEM_STOCK("Exit", "Exit the Application",
			 pdscanner_quit, GNOME_STOCK_PIXMAP_EXIT),
   GNOMEUIINFO_SEPARATOR,
     {
	GNOME_APP_UI_ITEM,
	N_("Scan"),
	N_("Scan the selected ports"),
	pdscanner_scan, NULL,
	NULL,
	GNOME_APP_PIXMAP_DATA, scan_xpm,
	'S', GDK_CONTROL_MASK, NULL
     },
     {
	GNOME_APP_UI_ITEM,
	N_("Clear"),
	N_("Clear the output list"),
	pdscanner_clear, NULL,
	NULL,
	GNOME_APP_PIXMAP_DATA, clear_xpm,
	'C', GDK_CONTROL_MASK, NULL
     },
   GNOMEUIINFO_SEPARATOR,
   GNOMEUIINFO_ITEM_STOCK(N_("About"), N_("About this program"),
			  pdscanner_about, GNOME_STOCK_PIXMAP_ABOUT),
   GNOMEUIINFO_END
};

/* Creates a button with pixmap and label
 * on it with */

GtkWidget *gnome_pixmap_button_new_with_label(gchar **data, char *text, int width, 
					      int height, int padding)
{
   GtkWidget *hbox;
   GtkWidget *pixmap;
   GtkWidget *label;
   GtkWidget *button;
   
   hbox = gtk_hbox_new(FALSE, 0);
   pixmap = gnome_pixmap_new_from_xpm_d_at_size(data, width, height);
   gtk_box_pack_start(GTK_BOX(hbox), pixmap, TRUE, TRUE, padding);
   label = gtk_label_new(text);
   gtk_box_pack_end(GTK_BOX(hbox), label, TRUE, TRUE, padding);
   button = gtk_button_new();
   gtk_container_border_width(GTK_CONTAINER(button), padding);
   gtk_container_add(GTK_CONTAINER(button), hbox);
   
   return(button);
}

void create_pdscanner(void)
{  
   GtkWidget *table; 
   GtkWidget *label;
   GtkWidget *scrolled_window;
   GtkWidget *vpane;
   gchar *titles[] = { "Port", "Service", NULL };

   /* create our pane */
   vpane = gtk_vpaned_new();
   gtk_paned_set_position(GTK_PANED(vpane), 135);
   
   /* create the main window */
   pdscanner.main_window = gnome_app_new(PACKAGE, PACKAGE);
   gtk_window_set_default_size(GTK_WINDOW(pdscanner.main_window), 300, 500);
   gtk_container_border_width(GTK_CONTAINER(pdscanner.main_window), 2);
   gtk_signal_connect(GTK_OBJECT(pdscanner.main_window), "delete_event",
		      GTK_SIGNAL_FUNC(pdscanner_quit),
		      NULL);
   
   /* create the menubar */
   gnome_app_create_menus(GNOME_APP(pdscanner.main_window), menubar);

   /* create the toolbar */
   gnome_app_create_toolbar(GNOME_APP(pdscanner.main_window), toolbar);
   
   /* create the statusbar */
   pdscanner.status_bar = gnome_appbar_new(TRUE, TRUE, GNOME_PREFERENCES_USER);
   gnome_app_set_statusbar(GNOME_APP(pdscanner.main_window), pdscanner.status_bar);
   gnome_appbar_set_status(GNOME_APPBAR(pdscanner.status_bar), PACKAGE);
   pdscanner.progress_bar = gnome_appbar_get_progress(GNOME_APPBAR(pdscanner.status_bar));
   
   table = gtk_table_new(4, 3, FALSE);
   
   /* create our labels and entries */
   label = gtk_label_new(_("Host:"));
   gtk_table_attach(GTK_TABLE(table), label, 0, 1, 0, 1, 
		    GTK_EXPAND, GTK_EXPAND, 0, 0);
   pdscanner.host_entry = gtk_entry_new();
   gtk_table_attach(GTK_TABLE(table), pdscanner.host_entry, 1, 2, 0, 1,
		    GTK_SHRINK, GTK_SHRINK, 0, 0);
   
   label = gtk_label_new(_("Starting Port:"));
   gtk_table_attach(GTK_TABLE(table), label, 0, 1, 1, 2,
		    GTK_EXPAND, GTK_EXPAND, 0, 0);
   pdscanner.start_entry = gtk_entry_new();
   gtk_entry_set_text(GTK_ENTRY(pdscanner.start_entry), "1");
   gtk_table_attach(GTK_TABLE(table), pdscanner.start_entry, 1, 2, 1, 2,
		    GTK_EXPAND, GTK_EXPAND, 0, 0);
   
   label = gtk_label_new(_("Ending Port:"));
   gtk_table_attach(GTK_TABLE(table), label, 0, 1, 2, 3,
		    GTK_EXPAND, GTK_EXPAND, 0, 0);
   pdscanner.end_entry = gtk_entry_new();
   gtk_entry_set_text(GTK_ENTRY(pdscanner.end_entry), "1024");
   gtk_table_attach(GTK_TABLE(table), pdscanner.end_entry, 1, 2, 2, 3,
		    GTK_EXPAND , GTK_EXPAND, 0, 0);

   /* create our buttons */
   pdscanner.scan_button = gnome_pixmap_button_new_with_label(scan_xpm, "Scan", 22, 22, 2);
   gtk_table_attach(GTK_TABLE(table), pdscanner.scan_button, 0, 1, 3, 4,
		    GTK_EXPAND | GTK_SHRINK,
		    GTK_EXPAND | GTK_SHRINK, 0, 0);
   gtk_signal_connect(GTK_OBJECT(pdscanner.scan_button), "clicked",
		      GTK_SIGNAL_FUNC(pdscanner_scan), NULL);
   
   pdscanner.clear_button = gnome_pixmap_button_new_with_label(clear_xpm, "Clear", 22, 22, 2);
   gtk_table_attach(GTK_TABLE(table), pdscanner.clear_button, 1, 2, 3, 4,
		    GTK_EXPAND | GTK_SHRINK,
		    GTK_EXPAND | GTK_SHRINK, 0, 0);
   gtk_signal_connect(GTK_OBJECT(pdscanner.clear_button), "clicked",
		      GTK_SIGNAL_FUNC(pdscanner_clear), NULL);
		      
   pdscanner.exit_button = gnome_stock_button(GNOME_STOCK_BUTTON_CLOSE);
   gtk_table_attach(GTK_TABLE(table), pdscanner.exit_button, 2, 3, 3, 4,
		    GTK_EXPAND | GTK_SHRINK,
		    GTK_EXPAND | GTK_SHRINK, 0, 0);
   gtk_signal_connect(GTK_OBJECT(pdscanner.exit_button), "clicked",
		      GTK_SIGNAL_FUNC(pdscanner_quit), NULL);
   
   scrolled_window = gtk_scrolled_window_new(NULL, NULL);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled_window),
				  GTK_POLICY_AUTOMATIC,
				  GTK_POLICY_ALWAYS);

   /* create the output list */
   pdscanner.output_list = gtk_clist_new_with_titles(2, titles);
   gtk_clist_column_titles_show(GTK_CLIST(pdscanner.output_list));
   gtk_clist_set_column_width(GTK_CLIST(pdscanner.output_list), 0, 50);
   gtk_container_add(GTK_CONTAINER(scrolled_window), pdscanner.output_list);
   
   /* fill the contents of our panes */
   gtk_paned_add1(GTK_PANED(vpane), table);
   gtk_paned_add2(GTK_PANED(vpane), scrolled_window);
   
   /* fill our app with our panes */
   gnome_app_set_contents(GNOME_APP(pdscanner.main_window), vpane);
   
   /* boom. show everything */
   gtk_widget_show_all(pdscanner.main_window);
}
