/*****************************************************************************
 * PDSCANNER - A port scanner for GNOME                                      *
 * Copyright (C) 2000 Scott Guilbeaux <scottg@viptx.net>                     *
 *                                                                           *
 * This program is free software; you can redistribute it and/or modify      *
 * it under the terms of the GNU General Public License as published by      *
 * the Free Software Foundation; either version 2 of the License, or         *
 * (at your option) any later version.                                       *
 *                                                                           *
 * This program is distributed in the hope that it will be useful,           *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
 * GNU General Public License for more details.                              *
 *                                                                           *
 * You should have received a copy of the GNU General Public License         *
 * along with this program; if not, write to the Free Software               *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA *
 *****************************************************************************/

#include "pdscanner.h"

/* Just returns whether the host was
 * found or not */

void verify_host(void)
{     
   hent = gethostbyname(target_host.host_name);
   if(hent == NULL)
     target_host.valid = FALSE;
   else
     target_host.valid = TRUE;
}

/* Thread function to check the selected ports
 * and report the results */

void check_ports(void *arg)
{
   int i = 0;
   int retval = 0;
   struct sockaddr_in pin;
   int sd;
   gfloat increment, value;
   gchar *results[2];
   struct servent *services;
   gchar *message;
   
   increment = (gfloat)1/(target_host.ending_port - target_host.starting_port);
   value = increment;
   if(value > 1 || value == 0)
     value = 1;
   
   for(i = target_host.starting_port; i <= target_host.ending_port; i++)
     {
	bzero(&pin, sizeof(pin));
	pin.sin_family =AF_INET;
	pin.sin_addr.s_addr = htonl(INADDR_ANY);
	pin.sin_addr.s_addr = ((struct in_addr *)(hent->h_addr))->s_addr;
	pin.sin_port = htons(i);
	sd = socket(AF_INET, SOCK_STREAM, 0);
	retval = connect(sd, (void *)&pin, sizeof(pin));
	message = g_strdup_printf("Scanning port %d", i);
	gdk_threads_enter();
	gnome_appbar_set_status(GNOME_APPBAR(pdscanner.status_bar), message);
	gdk_threads_leave();
	if(retval == 0)
	  {
	     results[0] = g_strdup_printf("%d", i);
	     services = getservbyport(htons(i), "tcp");
	     if(services != NULL)
	       results[1] = g_strdup_printf("%s", services->s_name);
	     else
	       results[1] = g_strdup_printf("Unknown port");
	     gdk_threads_enter();
	     gtk_clist_freeze(GTK_CLIST(pdscanner.output_list));
	     gtk_clist_append(GTK_CLIST(pdscanner.output_list), results);
	     gtk_clist_thaw(GTK_CLIST(pdscanner.output_list));
	     gdk_threads_leave();
	  }
	close(sd);
	gdk_threads_enter();
	gtk_progress_set_percentage(GTK_PROGRESS(pdscanner.progress_bar), value);
	gdk_threads_leave();
	value += increment;
	if(value > 1 || value == 0)
	  value = 1;
     }
   gdk_threads_enter();
   gtk_widget_set_sensitive(GTK_WIDGET(pdscanner.scan_button), TRUE);
   gtk_widget_set_sensitive(GTK_WIDGET(pdscanner.clear_button), TRUE);
   gnome_appbar_set_status(GNOME_APPBAR(pdscanner.status_bar), "Done");
   gdk_threads_leave();
#ifdef DEBUG
   g_print("%s: Thread exited\n", PACKAGE);
#endif
}
